/*
 * Copyright (c) 2002 Hamish Rodda <rodda@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef KRANDRTRAY_H
#define KRANDRTRAY_H

#include <ksystemtray.h>

#include "randrdisplay.h"
class KHelpMenu;
class QAction;
class KPopupMenu;

class KRandRSystemTray : public KSystemTray
{
	Q_OBJECT

public:
	KRandRSystemTray(RandRDisplay *dpy, QWidget* parent = 0, const char *name = 0);

	virtual void contextMenuAboutToShow(KPopupMenu* menu);

	void configChanged();

public slots:
	void slotSwitchDisplay();

protected slots:
	void slotScreenActivated();
	void slotResolutionChanged(int parameter);
	void slotOrientationChanged(int parameter);
	void slotRefreshRateChanged(int parameter);
	void slotPrefs();
	void slotToggleRunStartup();

protected:
	void mousePressEvent( QMouseEvent *e );

private:
	void populateMenu(KPopupMenu* menu);
	void populateLegacyMenu(KPopupMenu* menu);

	// helper functions
	void populateRotations(KPopupMenu *menu, int rotations, int rotation, QObject *receiver, const char *member);
	void populateSizes(KPopupMenu *menu, SizeList sizes, QSize size, QObject *receiver, const char *member);
	void populateRates(KPopupMenu *menu, RateList rates, float rate, QObject *receiver, const char *member);
	KHelpMenu* m_help;
	bool m_popupUp;
	QValueList<KPopupMenu*> m_screenPopups;
	RandRDisplay *m_display;
	bool m_runStartup;
};

#endif
